@@ -21,14 +21,14 @@ def test_basic_args():
     def fn(*args, **kwargs):
         arr.append(1)
 
-    s_args = [1,2,3]
+    s_args = [1, 2, 3]
     fn(*s_args)
     fn(*s_args)
     c_args = [[1], "asdjf", {'a': 5}]
     fn(*c_args)
     fn(*c_args)
-    kw_args = {'a': 234, 'b': [1,2,"asdf"], 'c': [5,6]}
-    kw_args_2 = {'a': 234, 'b': [1,3,"asdf"], 'c': [5,6]}
+    kw_args = {'a': 234, 'b': [1, 2, "asdf"], 'c': [5, 6]}
+    kw_args_2 = {'a': 234, 'b': [1, 3, "asdf"], 'c': [5, 6]}
     fn(*c_args, **kw_args)
     fn(*c_args, **kw_args_2)
     fn(*c_args, **kw_args)
@@ -45,9 +45,9 @@ def test_timeout():
     def fn(*args, **kwargs):
         arr.append(1)
 
-    fn(1,2,3)
+    fn(1, 2, 3)
     time.sleep(.2)
-    fn(1,2,3)
+    fn(1, 2, 3)
 
     assert arr == [1, 1]
 
@@ -58,10 +58,10 @@ def test_auto_flush():
     def fn(*args, **kwargs):
         pass
 
-    fn(1,2,3)
+    fn(1, 2, 3)
     assert len(memoize_inst.cache.keys()) == 1
     time.sleep(.2)
-    fn(1,2,3)
+    fn(1, 2, 3)
     assert len(memoize_inst.cache.keys()) == 1
 
 def test_manual_flush():
@@ -71,11 +71,39 @@ def test_manual_flush():
     def fn(*args, **kwargs):
         pass
 
-    fn(1,2,3)
+    fn(1, 2, 3)
     assert len(memoize_inst.cache.keys()) == 1
     time.sleep(.2)
-    fn(3,4,5)
+    fn(3, 4, 5)
     assert len(memoize_inst.cache.keys()) == 2
     time.sleep(.2)
     fn.flush_cache()
     assert len(memoize_inst.cache.keys()) == 0
+
+def test_class_method():
+    import random
+
+    memoizer = memoize(manual_flush=True, instance_method=True)
+
+    class foo(object):
+        @memoizer
+        def bar(self, *args):
+            return random.random()
+
+    x = foo()
+    x2 = foo()
+
+    assert x.bar('a', 'b') != x2.bar('a', 'b')
+    assert x.bar('a', 'b') == x.bar('a', 'b')
+    assert x.bar('a', 'b') != x.bar('a', 'd')
+    assert x2.bar('a', 'b') == x2.bar('a', 'b')
+
+    # the memoizer should have made private caches for each instance
+    assert len(memoizer.cache) == 0
+
+    # now make sure that they don't share caches
+    res1 = x.bar('a', 'b')
+    res2 = x2.bar('a', 'b')
+    x.bar.flush_cache()
+    assert res1 != x.bar('a', 'b')
+    assert res2 == x2.bar('a', 'b')
